@@ -62,10 +62,12 @@ pub(crate) const RESERVED_VERSION_NUM_DEFAULT: usize = 10;
 const BASE_DIR_VAR: &str = "VSDB_BASE_DIR";
 
 static VSDB_BASE_DIR: Lazy<Mutex<String>> = Lazy::new(|| Mutex::new(gen_data_dir()));
+
 static VSDB_CUSTOM_DIR: Lazy<String> = Lazy::new(|| {
-    let r = VSDB_BASE_DIR.lock().clone() + "__CUSTOM__";
-    env::set_var("VSDB_CUSTOM_DIR", &r);
-    r
+    let d = VSDB_BASE_DIR.lock().clone() + "/__CUSTOM__";
+    fs::create_dir_all(&d).unwrap();
+    env::set_var("VSDB_CUSTOM_DIR", &d);
+    d
 });
 
 #[cfg(all(feature = "sled_engine", not(feature = "rocks_engine")))]
