@@ -26,7 +26,7 @@ pub(super) const RESERVED_VERSION_NUM_DEFAULT: usize = 10;
 ////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////
 
-#[derive(Default, Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
 pub(super) struct MapxRawVs {
     default_branch: BranchID,
 
@@ -52,7 +52,15 @@ pub(super) struct MapxRawVs {
 impl MapxRawVs {
     #[inline(always)]
     pub(super) fn new() -> Self {
-        let mut ret = Self::default();
+        let mut ret = Self {
+            default_branch: BranchID::default(),
+            branch_name_to_branch_id: MapxOrdRawKey::new(),
+            version_name_to_version_id: MapxOrdRawKey::new(),
+            branch_to_parent: MapxOrd::new(),
+            branch_to_created_versions: MapxOrd::new(),
+            version_to_change_set: MapxOrd::new(),
+            layered_kv: MapxOrdRawKey::new(),
+        };
         ret.init();
         ret
     }
@@ -1005,6 +1013,12 @@ impl MapxRawVs {
     }
 }
 
+impl Default for MapxRawVs {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 ////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////
 
